// MainFrm.cpp : implementation of the CMainFrame class
//

#include "stdafx.h"
#include "Notenverwaltung.h"

#include "MainFrm.h"
#include "LeftView.h"
#include "NotenverwaltungView.h"
#pragma warning (disable : 4786)
#include "NotenverwaltungDoc.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CMainFrame

const char* neuesFachString = "Neues Fach...";

IMPLEMENT_DYNCREATE(CMainFrame, CFrameWnd)

BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
	//{{AFX_MSG_MAP(CMainFrame)
	ON_WM_CREATE()
	//}}AFX_MSG_MAP
	ON_UPDATE_COMMAND_UI_RANGE(AFX_ID_VIEW_MINIMUM, AFX_ID_VIEW_MAXIMUM, OnUpdateViewStyles)
	ON_COMMAND_RANGE(AFX_ID_VIEW_MINIMUM, AFX_ID_VIEW_MAXIMUM, OnViewStyle)
    ON_CONTROL(CBN_SELCHANGE, IDC_FACH, OnSelectFach)
END_MESSAGE_MAP()

static UINT indicators[] =
{
	ID_SEPARATOR,           // status line indicator
	ID_INDICATOR_CAPS,
	ID_INDICATOR_NUM,
	ID_INDICATOR_SCRL,
};

/////////////////////////////////////////////////////////////////////////////
// CMainFrame construction/destruction

CMainFrame::CMainFrame()
{
}

CMainFrame::~CMainFrame()
{
}

int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	if (CFrameWnd::OnCreate(lpCreateStruct) == -1)
		return -1;
	
	if (!m_wndToolBar.CreateEx(this) ||
		!m_wndToolBar.LoadToolBar(IDR_MAINFRAME))
	{
		TRACE0("Failed to create toolbar\n");
		return -1;      // fail to create
	}
	if (!m_wndDlgBar.Create(this, IDR_MAINFRAME, 
		CBRS_ALIGN_TOP, AFX_IDW_DIALOGBAR))
	{
		TRACE0("Failed to create dialogbar\n");
		return -1;		// fail to create
	}

	if (!m_wndReBar.Create(this) ||
		!m_wndReBar.AddBar(&m_wndToolBar) ||
		!m_wndReBar.AddBar(&m_wndDlgBar))
	{
		TRACE0("Failed to create rebar\n");
		return -1;      // fail to create
	}

	if (!m_wndStatusBar.Create(this) ||
		!m_wndStatusBar.SetIndicators(indicators,
		  sizeof(indicators)/sizeof(UINT)))
	{
		TRACE0("Failed to create status bar\n");
		return -1;      // fail to create
	}

	m_wndToolBar.SetBarStyle(m_wndToolBar.GetBarStyle() |
		CBRS_TOOLTIPS | CBRS_FLYBY);

    CWnd* comboboxWindow = m_wndDlgBar.GetDlgItem(IDC_FACH);
    if(comboboxWindow)
    {
        CComboBox combobox;
        combobox.Attach(comboboxWindow->m_hWnd);
        combobox.InsertString(-1, neuesFachString);
        combobox.Detach();
    }

	return 0;
}

BOOL CMainFrame::OnCreateClient(LPCREATESTRUCT /*lpcs*/,
	CCreateContext* pContext)
{
	// create splitter window
	if (!m_wndSplitter.CreateStatic(this, 1, 2))
		return FALSE;

	if (!m_wndSplitter.CreateView(0, 0, RUNTIME_CLASS(CLeftView), CSize(100, 100), pContext) ||
		!m_wndSplitter.CreateView(0, 1, RUNTIME_CLASS(CNotenverwaltungView), CSize(100, 100), pContext))
	{
		m_wndSplitter.DestroyWindow();
		return FALSE;
	}

    CNotenverwaltungView* pView = GetRightPane();
    CNotenverwaltungDoc* doc = pView->GetDocument();
    doc->addFachObserver(this);

	return TRUE;
}

BOOL CMainFrame::PreCreateWindow(CREATESTRUCT& cs)
{
	if( !CFrameWnd::PreCreateWindow(cs) )
		return FALSE;
	return TRUE;
}

/////////////////////////////////////////////////////////////////////////////
// CMainFrame diagnostics

#ifdef _DEBUG
void CMainFrame::AssertValid() const
{
	CFrameWnd::AssertValid();
}

void CMainFrame::Dump(CDumpContext& dc) const
{
	CFrameWnd::Dump(dc);
}



#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CMainFrame message handlers

CNotenverwaltungView* CMainFrame::GetRightPane()
{
	CWnd* pWnd = m_wndSplitter.GetPane(0, 1);
	CNotenverwaltungView* pView = DYNAMIC_DOWNCAST(CNotenverwaltungView, pWnd);
	return pView;
}

void CMainFrame::OnUpdateViewStyles(CCmdUI* pCmdUI)
{

	CNotenverwaltungView* pView = GetRightPane(); 


	if (pView == NULL)
		pCmdUI->Enable(FALSE);
	else
	{
		DWORD dwStyle = pView->GetStyle() & LVS_TYPEMASK;

		if (pCmdUI->m_nID == ID_VIEW_LINEUP)
		{
			if (dwStyle == LVS_ICON || dwStyle == LVS_SMALLICON)
				pCmdUI->Enable();
			else
				pCmdUI->Enable(FALSE);
		}
		else
		{
			pCmdUI->Enable();
			BOOL bChecked = FALSE;

			switch (pCmdUI->m_nID)
			{
			case ID_VIEW_DETAILS:
				bChecked = (dwStyle == LVS_REPORT);
				break;

			case ID_VIEW_SMALLICON:
				bChecked = (dwStyle == LVS_SMALLICON);
				break;

			case ID_VIEW_LARGEICON:
				bChecked = (dwStyle == LVS_ICON);
				break;

			case ID_VIEW_LIST:
				bChecked = (dwStyle == LVS_LIST);
				break;

			default:
				bChecked = FALSE;
				break;
			}

			pCmdUI->SetRadio(bChecked ? 1 : 0);
		}
	}
}


void CMainFrame::OnViewStyle(UINT nCommandID)
{
	CNotenverwaltungView* pView = GetRightPane();

	if (pView != NULL)
	{
		DWORD dwStyle = -1;

		switch (nCommandID)
		{
		case ID_VIEW_LINEUP:
			{
				CListCtrl& refListCtrl = pView->GetListCtrl();
				refListCtrl.Arrange(LVA_SNAPTOGRID);
			}
			break;

		case ID_VIEW_DETAILS:
			dwStyle = LVS_REPORT;
			break;

		case ID_VIEW_SMALLICON:
			dwStyle = LVS_SMALLICON;
			break;

		case ID_VIEW_LARGEICON:
			dwStyle = LVS_ICON;
			break;

		case ID_VIEW_LIST:
			dwStyle = LVS_LIST;
			break;
		}

		if (dwStyle != -1)
			pView->ModifyStyle(LVS_TYPEMASK, dwStyle);
	}
}

void CMainFrame::OnSelectFach()
{
    CWnd* comboboxWindow = m_wndDlgBar.GetDlgItem(IDC_FACH);
    if(comboboxWindow)
    {
        CString fachname;
        comboboxWindow->GetWindowText(fachname);
        CNotenverwaltungView* pView = GetRightPane();
        CNotenverwaltungDoc* doc = pView->GetDocument();

        if(fachname == neuesFachString)
        {
            doc->OnBearbeitenNeuesfacherzeugen();
        }
        else
        {
            doc->setAktuellesFach(fachname);   
        }
    }
}

void CMainFrame::onNeuesFach(const CString& neuesFach)
{
    CWnd* comboboxWindow = m_wndDlgBar.GetDlgItem(IDC_FACH);
    if(comboboxWindow)
    {
        CComboBox combobox;
        combobox.Attach(comboboxWindow->m_hWnd);
        combobox.InsertString(-1, neuesFach);
        combobox.Detach();
    }
}

void CMainFrame::onNeuesAktuellesFach(const CString& neuesAktuellesFach)
{
    CWnd* comboboxWindow = m_wndDlgBar.GetDlgItem(IDC_FACH);
    if(comboboxWindow)
    {
        CComboBox combobox;
        combobox.Attach(comboboxWindow->m_hWnd);
        combobox.SelectString(-1, neuesAktuellesFach);
        combobox.Detach();
    }
}

void CMainFrame::onNeueFaecher(const CStringArray& fachNamen)
{
    CWnd* comboboxWindow = m_wndDlgBar.GetDlgItem(IDC_FACH);
    if(comboboxWindow)
    {
        CComboBox combobox;
        combobox.Attach(comboboxWindow->m_hWnd);
        combobox.ResetContent();
        combobox.InsertString(0, neuesFachString);
        for(int i = 0; i < fachNamen.GetSize(); ++i)
        {
            combobox.InsertString(i+1, fachNamen[i]);
        }
        combobox.Detach();
    }
}